import { z } from 'zod';
import { type MaybePromise } from '../utils.js';
import { type ErrorInferenceObject, type SafeResult } from './shared.js';
export * from './shared.js';
export { z } from 'zod';
export { getApiContext } from '../store.js';
export type Accept = 'form' | 'json';
export type InputSchema<T extends Accept> = T extends 'form' ? z.AnyZodObject | z.ZodType<FormData> : z.ZodType;
export type ActionClient<TOutput, TAccept extends Accept, TInputSchema extends InputSchema<TAccept>> = ((input: TAccept extends 'form' ? FormData : z.input<TInputSchema>) => Promise<Awaited<TOutput>>) & {
    safe: (input: TAccept extends 'form' ? FormData : z.input<TInputSchema>) => Promise<SafeResult<z.infer<TInputSchema> extends ErrorInferenceObject ? z.infer<TInputSchema> : ErrorInferenceObject, Awaited<TOutput>>>;
};
export declare function defineAction<TOutput, TAccept extends Accept = 'json', TInputSchema extends InputSchema<Accept> = TAccept extends 'form' ? z.ZodType<FormData> : never>({ accept, input: inputSchema, handler, }: {
    input?: TInputSchema;
    accept?: TAccept;
    handler: (input: z.infer<TInputSchema>) => MaybePromise<TOutput>;
}): ActionClient<TOutput, TAccept, TInputSchema>;
/** Transform form data to an object based on a Zod schema. */
export declare function formDataToObject<T extends z.AnyZodObject>(formData: FormData, schema: T): Record<string, unknown>;
